==> duplicate-package-checker-webpack-plugin-2.1.2.tgz: duplicate-package-checker-webpack-plugin/README.md <==
# Installation
> `npm install --save @types/duplicate-package-checker-webpack-plugin`

# Summary
This package contains type definitions for duplicate-package-checker-webpack-plugin (https://github.com/darrenscerri/duplicate-package-checker-webpack-plugin#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/duplicate-package-checker-webpack-plugin.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/duplicate-package-checker-webpack-plugin/index.d.ts)
````ts
// Type definitions for duplicate-package-checker-webpack-plugin 2.1
// Project: https://github.com/darrenscerri/duplicate-package-checker-webpack-plugin#readme
// Definitions by: Matt Traynham <https://github.com/mtraynham>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.7

import { Plugin } from 'webpack';

export = DuplicatePackageCheckerWebpackPlugin;

declare class DuplicatePackageCheckerWebpackPlugin extends Plugin {
    constructor(options?: DuplicatePackageCheckerWebpackPlugin.Options);
}

declare namespace DuplicatePackageCheckerWebpackPlugin {
    /** The properties of the instance of a package */
    interface PackageInstanceProperties {
        /** The name of the package */
        name: string;
        /** The version of the package */
        version: string;
        /** Absolute path to the package */
        path: string;
        /** Absolute path to the module that requested the package */
        issuer?: string | undefined;
    }

    /** The configurable options for the plugin */
    interface Options {
        /** Also show module that is requiring each duplicate package (default: false) */
        verbose?: boolean | undefined;
        /** Emit errors instead of warnings (default: false) */
        emitError?: boolean | undefined;
        /** Show help message if duplicate packages are found (default: true) */
        showHelp?: boolean | undefined;
        /** Warn also if major versions differ (default: true) */
        strict?: boolean | undefined;

        /**
         * Exclude instances of packages from the results.
         * If all instances of a package are excluded, or all instances except one,
         * then the package is no longer considered duplicated and won't be emitted as a warning/error.
         * @param instance The instance of a package being evaluated for exclusion.
         * @returns true to exclude the instance, false otherwise
         */
        exclude?: ((instance: PackageInstanceProperties) => boolean) | undefined;
    }
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 12:00:58 GMT
 * Dependencies: [@types/webpack](https://npmjs.com/package/@types/webpack)
 * Global values: none

# Credits
These definitions were written by [Matt Traynham](https://github.com/mtraynham).

==> duplicate-package-checker-webpack-plugin-2.1.4.tgz: duplicate-package-checker-webpack-plugin/README.md <==
# Installation
> `npm install --save @types/duplicate-package-checker-webpack-plugin`

# Summary
This package contains type definitions for duplicate-package-checker-webpack-plugin (https://github.com/darrenscerri/duplicate-package-checker-webpack-plugin#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/duplicate-package-checker-webpack-plugin.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/duplicate-package-checker-webpack-plugin/index.d.ts)
````ts
import { Plugin } from "webpack";

export = DuplicatePackageCheckerWebpackPlugin;

declare class DuplicatePackageCheckerWebpackPlugin extends Plugin {
    constructor(options?: DuplicatePackageCheckerWebpackPlugin.Options);
}

declare namespace DuplicatePackageCheckerWebpackPlugin {
    /** The properties of the instance of a package */
    interface PackageInstanceProperties {
        /** The name of the package */
        name: string;
        /** The version of the package */
        version: string;
        /** Absolute path to the package */
        path: string;
        /** Absolute path to the module that requested the package */
        issuer?: string | undefined;
    }

    /** The configurable options for the plugin */
    interface Options {
        /** Also show module that is requiring each duplicate package (default: false) */
        verbose?: boolean | undefined;
        /** Emit errors instead of warnings (default: false) */
        emitError?: boolean | undefined;
        /** Show help message if duplicate packages are found (default: true) */
        showHelp?: boolean | undefined;
        /** Warn also if major versions differ (default: true) */
        strict?: boolean | undefined;

        /**
         * Exclude instances of packages from the results.
         * If all instances of a package are excluded, or all instances except one,
         * then the package is no longer considered duplicated and won't be emitted as a warning/error.
         * @param instance The instance of a package being evaluated for exclusion.
         * @returns true to exclude the instance, false otherwise
         */
        exclude?: ((instance: PackageInstanceProperties) => boolean) | undefined;
    }
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:34 GMT
 * Dependencies: [@types/webpack](https://npmjs.com/package/@types/webpack)

# Credits
These definitions were written by [Matt Traynham](https://github.com/mtraynham).
